==> roundcubemail-1.3.0-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/gl.js <==
tinymce.addI18n('gl',{
"Cut": "Cortar",
"Heading 5": "T\u00edtulo 5",
"Header 2": "Cabeceira 2",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "O seu navegador non admite o acceso directo ao portapapeis. Empregue os atallos de teclado Ctrl+X\/C\/V no seu canto.",
"Heading 4": "T\u00edtulo 4",
"Div": "Div",
"Heading 2": "T\u00edtulo 2",
"Paste": "Pegar",
"Close": "Pechar",
"Font Family": "Tipo de letra",
"Pre": "Pre",
"Align right": "Ali\u00f1ar \u00e1 dereita",
"New document": "Novo documento",
"Blockquote": "Bloque entre comi\u00f1as",
"Numbered list": "Lista numerada",
"Heading 1": "T\u00edtulo 1",
"Headings": "T\u00edtulo",
"Increase indent": "Aumentar a sangr\u00eda",
"Formats": "Formatos",
"Headers": "Cabeceiras",
"Select all": "Seleccionar todo",
"Header 3": "Cabeceira 3",
"Blocks": "Bloques",
"Undo": "Desfacer",
"Strikethrough": "Riscado",
"Bullet list": "Lista de vi\u00f1etas",
"Header 1": "Cabeceira 1",
"Superscript": "Super\u00edndice",
"Clear formatting": "Limpar o formato",
"Font Sizes": "Tama\u00f1o da letra",
"Subscript": "Sub\u00edndice",
"Header 6": "Cabeceira 6",
"Redo": "Refacer",
"Paragraph": "Par\u00e1grafo",
"Ok": "Aceptar",
"Bold": "Negra",
"Code": "C\u00f3digo",
"Italic": "Cursiva",
"Align center": "Ali\u00f1ar ao centro",
"Header 5": "Cabeceira 5",
"Heading 6": "T\u00edtulo 6",
"Heading 3": "T\u00edtulo 3",
"Decrease indent": "Reducir a sangr\u00eda",
"Header 4": "Cabeceira 4",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Neste momento o pegado est\u00e1 definido en modo de texto simple. Os contidos p\u00e9garanse como texto sen formato ata que se active esta opci\u00f3n.",
"Underline": "Subli\u00f1ado",
"Cancel": "Cancelar",
"Justify": "Xustificar",
"Inline": "En li\u00f1a",
"Copy": "Copiar",
"Align left": "Ali\u00f1ar \u00e1 esquerda",
"Visual aids": "Axudas visuais",
"Lower Greek": "Grega min\u00fascula",
"Square": "Cadrado",
"Default": "Predeterminada",
"Lower Alpha": "Alfa min\u00fascula",
"Circle": "Circulo",
"Disc": "Disco",
"Upper Alpha": "Alfa mai\u00fascula",
"Upper Roman": "Romana mai\u00fascula",
"Lower Roman": "Romana min\u00fascula",
"Name": "Nome",
"Anchor": "Ancoraxe",
"You have unsaved changes are you sure you want to navigate away?": "Ten cambios sen gardar. Confirma que quere sa\u00edr?",
"Restore last draft": "Restaurar o \u00faltimo borrador",
"Special character": "Car\u00e1cter especial",
"Source code": "C\u00f3digo fonte",
"B": "B",
"R": "R",
"G": "G",
"Color": "Color",
"Right to left": "De dereita a esquerda",
"Left to right": "De esquerda a dereita",
"Emoticons": "Emoticonas",
"Robots": "Robots",
"Document properties": "Propiedades do documento",
"Title": "T\u00edtulo",
"Keywords": "Palabras clave",
"Encoding": "Codificaci\u00f3n",
"Description": "Descrici\u00f3n",
"Author": "Autor",
"Fullscreen": "Pantalla completa",
"Horizontal line": "Li\u00f1a horizontal",
"Horizontal space": "Espazo horizontal",
"Insert\/edit image": "Inserir\/editar imaxe",
"General": "Xeral",
"Advanced": "Avanzado",
"Source": "Orixe",
"Border": "Bordo",
"Constrain proportions": "Restrinxir as proporci\u00f3ns",
"Vertical space": "Espazo vertical",
"Image description": "Descrici\u00f3n da imaxe",
"Style": "Estilo",
"Dimensions": "Dimensi\u00f3ns",
"Insert image": "Inserir imaxe",
"Zoom in": "Zoom in",
"Contrast": "Contrast",
"Back": "Back",
"Gamma": "Gamma",
"Flip horizontally": "Flip horizontally",
"Resize": "Resize",
"Sharpen": "Sharpen",
"Zoom out": "Zoom out",
"Image options": "Image options",
"Apply": "Apply",
"Brightness": "Brightness",
"Rotate clockwise": "Rotate clockwise",
"Rotate counterclockwise": "Rotate counterclockwise",
"Edit image": "Edit image",
"Color levels": "Color levels",
"Crop": "Crop",
"Orientation": "Orientation",
"Flip vertically": "Flip vertically",
"Invert": "Invert",
"Insert date\/time": "Inserir data\/hora",
"Remove link": "Retirar a ligaz\u00f3n",
"Url": "URL",
"Text to display": "Texto que amosar",
"Anchors": "Ancoraxes",
"Insert link": "Inserir ligaz\u00f3n",
"New window": "Nova xanela",
"None": "Ning\u00fan",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "O URL que introduciu semella seren unha ligaz\u00f3n externa. Quere engadirlle o prefixo http:\/\/ requirido?",
"Target": "Destino",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "O URL que introduciu semella seren un enderezo de correo. Quere engadirlle o prefixo mailto: requirido?",
"Insert\/edit link": "Inserir\/editar ligaz\u00f3n",
"Insert\/edit video": "Inserir\/editar v\u00eddeo",
"Poster": "Cartel",
"Alternative source": "Orixe alternativa",
"Paste your embed code below:": "Pegue embaixo o c\u00f3digo integrado:",
"Insert video": "Inserir v\u00eddeo",
"Embed": "Integrado",
"Nonbreaking space": "Espazo irromp\u00edbel",
"Page break": "Quebra de p\u00e1xina",
"Paste as text": "Pegar como texto",
"Preview": "Vista previa",
"Print": "Imprimir",
"Save": "Gardar",
"Could not find the specified string.": "Non foi pos\u00edbel atopar a cadea de texto especificada.",
"Replace": "Substitu\u00edr",
"Next": "Seguinte",
"Whole words": "Palabras completas",
"Find and replace": "Buscar e substitu\u00edr",
"Replace with": "Substitu\u00edr con",
"Find": "Buscar",
"Replace all": "Substitu\u00edr todo",
"Match case": "Distinguir mai\u00fasculas",
"Prev": "Anterior",
"Spellcheck": "Corrector ortogr\u00e1fico",
"Finish": "Rematar",
"Ignore all": "Ignorar todo",
"Ignore": "Ignorar",
"Add to Dictionary": "Add to Dictionary",
"Insert row before": "Inserir unha fila enriba",
"Rows": "Filas",
"Height": "Alto",
"Paste row after": "Pegar fila enriba",
"Alignment": "Ali\u00f1amento",
"Border color": "Border color",
"Column group": "Grupo de columnas",
"Row": "Fila",
"Insert column before": "Inserir columna \u00e1 esquerda",
"Split cell": "Dividir celas",
"Cell padding": "Marxe interior da cela",
"Cell spacing": "Marxe entre celas",
"Row type": "Tipo de fila",
"Insert table": "Inserir t\u00e1boa",
"Body": "Corpo",
"Caption": "Subt\u00edtulo",
"Footer": "Rodap\u00e9",
"Delete row": "Eliminar fila",
"Paste row before": "Pegar fila embaixo",
"Scope": "\u00c1mbito",
"Delete table": "Eliminar t\u00e1boa",
"H Align": "Ali\u00f1amento H",
"Top": "Arriba",
"Header cell": "Cela de cabeceira",
"Column": "Columna",
"Row group": "Grupo de filas",
"Cell": "Cela",
"Middle": "Medio",
"Cell type": "Tipo de cela",
"Copy row": "Copiar fila",
"Row properties": "Propiedades das filas",
"Table properties": "Propiedades da t\u00e1boa",
"Bottom": "Abaixo",
"V Align": "Ali\u00f1amento V",
"Header": "Cabeceira",
"Right": "Dereita",
"Insert column after": "Inserir columna \u00e1 dereita",
"Cols": "Cols.",
"Insert row after": "Inserir unha fila embaixo",
"Width": "Largo",
"Cell properties": "Propiedades da cela",
"Left": "Esquerda",
"Cut row": "Cortar fila",
"Delete column": "Eliminar columna",
"Center": "Centro",
"Merge cells": "Combinar celas",
"Insert template": "Inserir modelo",
"Templates": "Modelos",
"Background color": "Cor do fondo",
"Custom...": "Custom...",
"Custom color": "Custom color",
"No color": "No color",
"Text color": "Cor do texto",
"Show blocks": "Amosar os bloques",
"Show invisible characters": "Amosar caracteres invis\u00edbeis",
"Words: {0}": "Palabras: {0}",
"Insert": "Inserir",
"File": "Ficheiro",
"Edit": "Editar",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "\u00c1rea de texto mellorado. Prema ALT-F9 para o men\u00fa. Prema ALT-F10 para a barra de ferramentas. Prema ALT-0 para a axuda",
"Tools": "Ferramentas",
"View": "Ver",
"Table": "T\u00e1boa",
"Format": "Formato"
});

==> roundcubemail-1.3.5-1-any.pkg.tar.xz: usr/share/webapps/roundcubemail/program/js/tinymce/langs/gl.js <==
tinymce.addI18n('gl',{
"Redo": "Refacer",
"Undo": "Desfacer",
"Cut": "Cortar",
"Copy": "Copiar",
"Paste": "Pegar",
"Select all": "Seleccionar todo",
"New document": "Novo documento",
"Ok": "Aceptar",
"Cancel": "Cancelar",
"Visual aids": "Axudas visuais",
"Bold": "Negra",
"Italic": "Cursiva",
"Underline": "Subli\u00f1ado",
"Strikethrough": "Riscado",
"Superscript": "Super\u00edndice",
"Subscript": "Sub\u00edndice",
"Clear formatting": "Limpar o formato",
"Align left": "Ali\u00f1ar \u00e1 esquerda",
"Align center": "Ali\u00f1ar ao centro",
"Align right": "Ali\u00f1ar \u00e1 dereita",
"Justify": "Xustificar",
"Bullet list": "Lista de vi\u00f1etas",
"Numbered list": "Lista numerada",
"Decrease indent": "Reducir a sangr\u00eda",
"Increase indent": "Aumentar a sangr\u00eda",
"Close": "Pechar",
"Formats": "Formatos",
"Your browser doesn't support direct access to the clipboard. Please use the Ctrl+X\/C\/V keyboard shortcuts instead.": "O seu navegador non admite o acceso directo ao portapapeis. Empregue os atallos de teclado Ctrl+X\/C\/V no seu canto.",
"Headers": "Cabeceiras",
"Header 1": "Cabeceira 1",
"Header 2": "Cabeceira 2",
"Header 3": "Cabeceira 3",
"Header 4": "Cabeceira 4",
"Header 5": "Cabeceira 5",
"Header 6": "Cabeceira 6",
"Headings": "T\u00edtulo",
"Heading 1": "T\u00edtulo 1",
"Heading 2": "T\u00edtulo 2",
"Heading 3": "T\u00edtulo 3",
"Heading 4": "T\u00edtulo 4",
"Heading 5": "T\u00edtulo 5",
"Heading 6": "T\u00edtulo 6",
"Div": "Div",
"Pre": "Pre",
"Code": "C\u00f3digo",
"Paragraph": "Par\u00e1grafo",
"Blockquote": "Bloque entre comi\u00f1as",
"Inline": "En li\u00f1a",
"Blocks": "Bloques",
"Paste is now in plain text mode. Contents will now be pasted as plain text until you toggle this option off.": "Neste momento o pegado est\u00e1 definido en modo de texto simple. Os contidos p\u00e9garanse como texto sen formato ata que se active esta opci\u00f3n.",
"Font Family": "Tipo de letra",
"Font Sizes": "Tama\u00f1o da letra",
"Class": "Clase",
"Browse for an image": "Buscar unha imaxe",
"OR": "OU",
"Drop an image here": "Soltar unha imaxe",
"Upload": "Cargar",
"Default": "Predeterminada",
"Circle": "Circulo",
"Disc": "Disco",
"Square": "Cadrado",
"Lower Alpha": "Alfa min\u00fascula",
"Lower Greek": "Grega min\u00fascula",
"Lower Roman": "Romana min\u00fascula",
"Upper Alpha": "Alfa mai\u00fascula",
"Upper Roman": "Romana mai\u00fascula",
"Anchor": "Ancoraxe",
"Name": "Nome",
"Id": "ID",
"Id should start with a letter, followed only by letters, numbers, dashes, dots, colons or underscores.": "O ID debe comezar cunha letra, seguida s\u00f3 por letras, n\u00fameros, gui\u00f3ns, puntos, dos puntos ou gui\u00f3ns baixos.",
"You have unsaved changes are you sure you want to navigate away?": "Ten cambios sen gardar. Confirma que quere sa\u00edr?",
"Restore last draft": "Restaurar o \u00faltimo borrador",
"Special character": "Car\u00e1cter especial",
"Source code": "C\u00f3digo fonte",
"Insert\/Edit code sample": "Inserir\/editar mostra de c\u00f3digo",
"Language": "Idioma",
"Color": "Cor",
"R": "R",
"G": "G",
"B": "B",
"Left to right": "De esquerda a dereita",
"Right to left": "De dereita a esquerda",
"Emoticons": "Emoticonas",
"Document properties": "Propiedades do documento",
"Title": "T\u00edtulo",
"Keywords": "Palabras clave",
"Description": "Descrici\u00f3n",
"Robots": "Robots",
"Author": "Autor",
"Encoding": "Codificaci\u00f3n",
"Fullscreen": "Pantalla completa",
"Action": "Action",
"Shortcut": "Shortcut",
"Help": "Help",
"Address": "Address",
"Focus to menubar": "Focus to menubar",
"Focus to toolbar": "Focus to toolbar",
"Focus to element path": "Focus to element path",
"Focus to contextual toolbar": "Focus to contextual toolbar",
"Insert link (if link plugin activated)": "Insert link (if link plugin activated)",
"Save (if save plugin activated)": "Save (if save plugin activated)",
"Find (if searchreplace plugin activated)": "Find (if searchreplace plugin activated)",
"Plugins installed ({0}):": "Plugins installed ({0}):",
"Premium plugins:": "Premium plugins:",
"Learn more...": "Learn more...",
"You are using {0}": "You are using {0}",
"Horizontal line": "Li\u00f1a horizontal",
"Insert\/edit image": "Inserir\/editar imaxe",
"Image description": "Descrici\u00f3n da imaxe",
"Source": "Orixe",
"Dimensions": "Dimensi\u00f3ns",
"Constrain proportions": "Restrinxir as proporci\u00f3ns",
"General": "Xeral",
"Advanced": "Avanzado",
"Style": "Estilo",
"Vertical space": "Espazo vertical",
"Horizontal space": "Espazo horizontal",
"Border": "Bordo",
"Insert image": "Inserir imaxe",
"Image": "Imaxe",
"Image list": "Lista de imaxes",
"Rotate counterclockwise": "Rotate counterclockwise",
"Rotate clockwise": "Rotate clockwise",
"Flip vertically": "Flip vertically",
"Flip horizontally": "Flip horizontally",
"Edit image": "Edit image",
"Image options": "Image options",
"Zoom in": "Zoom in",
"Zoom out": "Zoom out",
"Crop": "Crop",
"Resize": "Resize",
"Orientation": "Orientation",
"Brightness": "Brightness",
"Sharpen": "Sharpen",
"Contrast": "Contrast",
"Color levels": "Color levels",
"Gamma": "Gamma",
"Invert": "Invert",
"Apply": "Apply",
"Back": "Back",
"Insert date\/time": "Inserir data\/hora",
"Date\/time": "Data\/hora",
"Insert link": "Inserir ligaz\u00f3n",
"Insert\/edit link": "Inserir\/editar ligaz\u00f3n",
"Text to display": "Texto que amosar",
"Url": "URL",
"Target": "Destino",
"None": "Ning\u00fan",
"New window": "Nova xanela",
"Remove link": "Retirar a ligaz\u00f3n",
"Anchors": "Ancoraxes",
"Link": "Ligaz\u00f3n",
"Paste or type a link": "Pegue ou escriba unha ligaz\u00f3n",
"The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?": "O URL que introduciu semella seren un enderezo de correo. Quere engadirlle o prefixo mailto: requirido?",
"The URL you entered seems to be an external link. Do you want to add the required http:\/\/ prefix?": "O URL que introduciu semella seren unha ligaz\u00f3n externa. Quere engadirlle o prefixo http:\/\/ requirido?",
"Link list": "Lista de ligaz\u00f3ns",
"Insert video": "Inserir v\u00eddeo",
"Insert\/edit video": "Inserir\/editar v\u00eddeo",
"Insert\/edit media": "Inserir\/editar medios",
"Alternative source": "Orixe alternativa",
"Poster": "Cartel",
"Paste your embed code below:": "Pegue embaixo o c\u00f3digo integrado:",
"Embed": "Integrado",
"Media": "Medios",
"Nonbreaking space": "Espazo irromp\u00edbel",
"Page break": "Quebra de p\u00e1xina",
"Paste as text": "Pegar como texto",
"Preview": "Vista previa",
"Print": "Imprimir",
"Save": "Gardar",
"Find": "Buscar",
"Replace with": "Substitu\u00edr con",
"Replace": "Substitu\u00edr",
"Replace all": "Substitu\u00edr todo",
"Prev": "Anterior",
"Next": "Seguinte",
"Find and replace": "Buscar e substitu\u00edr",
"Could not find the specified string.": "Non foi pos\u00edbel atopar a cadea de texto especificada.",
"Match case": "Distinguir mai\u00fasculas",
"Whole words": "Palabras completas",
"Spellcheck": "Corrector ortogr\u00e1fico",
"Ignore": "Ignorar",
"Ignore all": "Ignorar todo",
"Finish": "Rematar",
"Add to Dictionary": "Engadir ao dicionario",
"Insert table": "Inserir t\u00e1boa",
"Table properties": "Propiedades da t\u00e1boa",
"Delete table": "Eliminar t\u00e1boa",
"Cell": "Cela",
"Row": "Fila",
"Column": "Columna",
"Cell properties": "Propiedades da cela",
"Merge cells": "Combinar celas",
"Split cell": "Dividir celas",
"Insert row before": "Inserir unha fila enriba",
"Insert row after": "Inserir unha fila embaixo",
"Delete row": "Eliminar fila",
"Row properties": "Propiedades das filas",
"Cut row": "Cortar fila",
"Copy row": "Copiar fila",
"Paste row before": "Pegar fila embaixo",
"Paste row after": "Pegar fila enriba",
"Insert column before": "Inserir columna \u00e1 esquerda",
"Insert column after": "Inserir columna \u00e1 dereita",
"Delete column": "Eliminar columna",
"Cols": "Cols.",
"Rows": "Filas",
"Width": "Largo",
"Height": "Alto",
"Cell spacing": "Marxe entre celas",
"Cell padding": "Marxe interior da cela",
"Caption": "Subt\u00edtulo",
"Left": "Esquerda",
"Center": "Centro",
"Right": "Dereita",
"Cell type": "Tipo de cela",
"Scope": "\u00c1mbito",
"Alignment": "Ali\u00f1amento",
"H Align": "Ali\u00f1amento H",
"V Align": "Ali\u00f1amento V",
"Top": "Arriba",
"Middle": "Medio",
"Bottom": "Abaixo",
"Header cell": "Cela de cabeceira",
"Row group": "Grupo de filas",
"Column group": "Grupo de columnas",
"Row type": "Tipo de fila",
"Header": "Cabeceira",
"Body": "Corpo",
"Footer": "Rodap\u00e9",
"Border color": "Cor do bordo",
"Insert template": "Inserir modelo",
"Templates": "Modelos",
"Template": "Modelo",
"Text color": "Cor do texto",
"Background color": "Cor do fondo",
"Custom...": "Personalizado...",
"Custom color": "Cor personalizado",
"No color": "Sen cor",
"Table of Contents": "\u00cdndice de contidos",
"Show blocks": "Amosar os bloques",
"Show invisible characters": "Amosar caracteres invis\u00edbeis",
"Words: {0}": "Palabras: {0}",
"File": "Ficheiro",
"Edit": "Editar",
"Insert": "Inserir",
"View": "Ver",
"Format": "Formato",
"Table": "T\u00e1boa",
"Tools": "Ferramentas",
"Rich Text Area. Press ALT-F9 for menu. Press ALT-F10 for toolbar. Press ALT-0 for help": "\u00c1rea de texto mellorado. Prema ALT-F9 para o men\u00fa. Prema ALT-F10 para a barra de ferramentas. Prema ALT-0 para a axuda"
});
